# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from copy import deepcopy
from typing import Any, TYPE_CHECKING

from azure.core.rest import HttpRequest, HttpResponse
from azure.mgmt.core import ARMPipelineClient

from . import models
from ._configuration import GuestConfigurationClientConfiguration
from ._serialization import Deserializer, Serializer
from .operations import (
    GuestConfigurationAssignmentReportsOperations,
    GuestConfigurationAssignmentReportsVMSSOperations,
    GuestConfigurationAssignmentsOperations,
    GuestConfigurationAssignmentsVMSSOperations,
    GuestConfigurationHCRPAssignmentReportsOperations,
    GuestConfigurationHCRPAssignmentsOperations,
    Operations,
)

if TYPE_CHECKING:
    # pylint: disable=unused-import,ungrouped-imports
    from azure.core.credentials import TokenCredential


class GuestConfigurationClient:  # pylint: disable=client-accepts-api-version-keyword,too-many-instance-attributes
    """Guest Configuration Client.

    :ivar guest_configuration_assignments: GuestConfigurationAssignmentsOperations operations
    :vartype guest_configuration_assignments:
     azure.mgmt.guestconfig.operations.GuestConfigurationAssignmentsOperations
    :ivar guest_configuration_assignment_reports: GuestConfigurationAssignmentReportsOperations
     operations
    :vartype guest_configuration_assignment_reports:
     azure.mgmt.guestconfig.operations.GuestConfigurationAssignmentReportsOperations
    :ivar guest_configuration_hcrp_assignments: GuestConfigurationHCRPAssignmentsOperations
     operations
    :vartype guest_configuration_hcrp_assignments:
     azure.mgmt.guestconfig.operations.GuestConfigurationHCRPAssignmentsOperations
    :ivar guest_configuration_hcrp_assignment_reports:
     GuestConfigurationHCRPAssignmentReportsOperations operations
    :vartype guest_configuration_hcrp_assignment_reports:
     azure.mgmt.guestconfig.operations.GuestConfigurationHCRPAssignmentReportsOperations
    :ivar guest_configuration_assignments_vmss: GuestConfigurationAssignmentsVMSSOperations
     operations
    :vartype guest_configuration_assignments_vmss:
     azure.mgmt.guestconfig.operations.GuestConfigurationAssignmentsVMSSOperations
    :ivar guest_configuration_assignment_reports_vmss:
     GuestConfigurationAssignmentReportsVMSSOperations operations
    :vartype guest_configuration_assignment_reports_vmss:
     azure.mgmt.guestconfig.operations.GuestConfigurationAssignmentReportsVMSSOperations
    :ivar operations: Operations operations
    :vartype operations: azure.mgmt.guestconfig.operations.Operations
    :param credential: Credential needed for the client to connect to Azure. Required.
    :type credential: ~azure.core.credentials.TokenCredential
    :param subscription_id: Subscription ID which uniquely identify Microsoft Azure subscription.
     The subscription ID forms part of the URI for every service call. Required.
    :type subscription_id: str
    :param base_url: Service URL. Default value is "https://management.azure.com".
    :type base_url: str
    :keyword api_version: Api Version. Default value is "2022-01-25". Note that overriding this
     default value may result in unsupported behavior.
    :paramtype api_version: str
    """

    def __init__(
        self,
        credential: "TokenCredential",
        subscription_id: str,
        base_url: str = "https://management.azure.com",
        **kwargs: Any
    ) -> None:
        self._config = GuestConfigurationClientConfiguration(
            credential=credential, subscription_id=subscription_id, **kwargs
        )
        self._client = ARMPipelineClient(base_url=base_url, config=self._config, **kwargs)

        client_models = {k: v for k, v in models.__dict__.items() if isinstance(v, type)}
        self._serialize = Serializer(client_models)
        self._deserialize = Deserializer(client_models)
        self._serialize.client_side_validation = False
        self.guest_configuration_assignments = GuestConfigurationAssignmentsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.guest_configuration_assignment_reports = GuestConfigurationAssignmentReportsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.guest_configuration_hcrp_assignments = GuestConfigurationHCRPAssignmentsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.guest_configuration_hcrp_assignment_reports = GuestConfigurationHCRPAssignmentReportsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.guest_configuration_assignments_vmss = GuestConfigurationAssignmentsVMSSOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.guest_configuration_assignment_reports_vmss = GuestConfigurationAssignmentReportsVMSSOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.operations = Operations(self._client, self._config, self._serialize, self._deserialize)

    def _send_request(self, request: HttpRequest, **kwargs: Any) -> HttpResponse:
        """Runs the network request through the client's chained policies.

        >>> from azure.core.rest import HttpRequest
        >>> request = HttpRequest("GET", "https://www.example.org/")
        <HttpRequest [GET], url: 'https://www.example.org/'>
        >>> response = client._send_request(request)
        <HttpResponse: 200 OK>

        For more information on this code flow, see https://aka.ms/azsdk/dpcodegen/python/send_request

        :param request: The network request you want to make. Required.
        :type request: ~azure.core.rest.HttpRequest
        :keyword bool stream: Whether the response payload will be streamed. Defaults to False.
        :return: The response of your network call. Does not do error handling on your response.
        :rtype: ~azure.core.rest.HttpResponse
        """

        request_copy = deepcopy(request)
        request_copy.url = self._client.format_url(request_copy.url)
        return self._client.send_request(request_copy, **kwargs)

    def close(self):
        # type: () -> None
        self._client.close()

    def __enter__(self):
        # type: () -> GuestConfigurationClient
        self._client.__enter__()
        return self

    def __exit__(self, *exc_details):
        # type: (Any) -> None
        self._client.__exit__(*exc_details)
